@@ -463,7 +463,7 @@ static GHashTable* attribute_types_hash;
 static hf_register_info* dynamic_hf;
 static guint dynamic_hf_size;
 
-static gboolean
+static bool
 attribute_types_update_cb(void *r, char **err)
 {
   attribute_type_t *rec = (attribute_type_t *)r;
@@ -2250,9 +2250,7 @@ void proto_register_ldap(void) {
 
   prefs_register_obsolete_preference(ldap_module, "max_pdu");
 
-  proto_cldap = proto_register_protocol(
-          "Connectionless Lightweight Directory Access Protocol",
-          "CLDAP", "cldap");
+  proto_cldap = proto_register_protocol("Connectionless Lightweight Directory Access Protocol", "CLDAP", "cldap");
   cldap_handle = register_dissector("cldap", dissect_mscldap, proto_cldap);
 
   ldap_tap=register_tap("ldap");
