@@ -213,14 +213,14 @@ void t38_add_address(packet_info *pinfo,
          * Check if the ip address and port combination is not
          * already registered as a conversation.
          */
-        p_conversation = find_conversation( setup_frame_number, addr, &null_addr, ENDPOINT_UDP, port, other_port,
+        p_conversation = find_conversation( setup_frame_number, addr, &null_addr, CONVERSATION_UDP, port, other_port,
                                 NO_ADDR_B | (!other_port ? NO_PORT_B : 0));
 
         /*
          * If not, create a new conversation.
          */
         if ( !p_conversation || p_conversation->setup_frame != setup_frame_number) {
-                p_conversation = conversation_new( setup_frame_number, addr, &null_addr, ENDPOINT_UDP,
+                p_conversation = conversation_new( setup_frame_number, addr, &null_addr, CONVERSATION_UDP,
                                            (guint32)port, (guint32)other_port,
                                                                    NO_ADDR2 | (!other_port ? NO_PORT2 : 0));
         }
@@ -257,6 +257,7 @@ void t38_add_address(packet_info *pinfo,
         p_conversation_data->src_t38_info.time_first_t4_data = 0;
         p_conversation_data->src_t38_info.additional_hdlc_data_field_counter = 0;
         p_conversation_data->src_t38_info.seqnum_prev_data_field = -1;
+        p_conversation_data->src_t38_info.next = NULL;
 
         p_conversation_data->dst_t38_info.reass_ID = 0;
         p_conversation_data->dst_t38_info.reass_start_seqnum = -1;
@@ -267,6 +268,7 @@ void t38_add_address(packet_info *pinfo,
         p_conversation_data->dst_t38_info.time_first_t4_data = 0;
         p_conversation_data->dst_t38_info.additional_hdlc_data_field_counter = 0;
         p_conversation_data->dst_t38_info.seqnum_prev_data_field = -1;
+        p_conversation_data->dst_t38_info.next = NULL;
 }
 
 
@@ -408,13 +410,13 @@ init_t38_info_conv(packet_info *pinfo)
 
 	/* find the conversation used for Reassemble and Setup Info */
 	p_conv = find_conversation(pinfo->num, &pinfo->net_dst, &pinfo->net_src,
-                                   conversation_pt_to_endpoint_type(pinfo->ptype),
+                                   conversation_pt_to_conversation_type(pinfo->ptype),
                                    pinfo->destport, pinfo->srcport, NO_ADDR_B | NO_PORT_B);
 
 	/* create a conv if it doen't exist */
 	if (!p_conv) {
 		p_conv = conversation_new(pinfo->num, &pinfo->net_src, &pinfo->net_dst,
-			      conversation_pt_to_endpoint_type(pinfo->ptype), pinfo->srcport, pinfo->destport, NO_ADDR2 | NO_PORT2);
+			      conversation_pt_to_conversation_type(pinfo->ptype), pinfo->srcport, pinfo->destport, NO_ADDR2 | NO_PORT2);
 
 		/* Set dissector */
 		conversation_set_dissector(p_conv, t38_udp_handle);
@@ -437,6 +439,7 @@ init_t38_info_conv(packet_info *pinfo)
 		p_t38_conv->src_t38_info.time_first_t4_data = 0;
 		p_t38_conv->src_t38_info.additional_hdlc_data_field_counter = 0;
 		p_t38_conv->src_t38_info.seqnum_prev_data_field = -1;
+		p_t38_conv->src_t38_info.next = NULL;
 
 		p_t38_conv->dst_t38_info.reass_ID = 0;
 		p_t38_conv->dst_t38_info.reass_start_seqnum = -1;
@@ -447,6 +450,7 @@ init_t38_info_conv(packet_info *pinfo)
 		p_t38_conv->dst_t38_info.time_first_t4_data = 0;
 		p_t38_conv->dst_t38_info.additional_hdlc_data_field_counter = 0;
 		p_t38_conv->dst_t38_info.seqnum_prev_data_field = -1;
+		p_t38_conv->dst_t38_info.next = NULL;
 
 		conversation_add_proto_data(p_conv, proto_t38, p_t38_conv);
 	}
@@ -706,7 +710,9 @@ proto_register_t38(void)
 	proto_register_subtree_array(ett, array_length(ett));
 	expert_t38 = expert_register_protocol(proto_t38);
 	expert_register_field_array(expert_t38, ei, array_length(ei));
-	register_dissector("t38_udp", dissect_t38_udp, proto_t38);
+	t38_udp_handle=register_dissector("t38_udp", dissect_t38_udp, proto_t38);
+	t38_tcp_handle=register_dissector("t38_tcp", dissect_t38_tcp, proto_t38);
+	t38_tcp_pdu_handle=register_dissector("t38_tcp_pdu", dissect_t38_tcp_pdu, proto_t38);
 
 	/* Register reassemble tables for HDLC */
 	reassembly_table_register(&data_reassembly_table,
@@ -749,9 +755,6 @@ proto_register_t38(void)
 void
 proto_reg_handoff_t38(void)
 {
-	t38_udp_handle=create_dissector_handle(dissect_t38_udp, proto_t38);
-	t38_tcp_handle=create_dissector_handle(dissect_t38_tcp, proto_t38);
-	t38_tcp_pdu_handle=create_dissector_handle(dissect_t38_tcp_pdu, proto_t38);
 	rtp_handle = find_dissector_add_dependency("rtp", proto_t38);
 	t30_hdlc_handle = find_dissector_add_dependency("t30.hdlc", proto_t38);
 	proto_acdr = proto_get_id_by_filter_name("acdr");
