@@ -840,19 +840,19 @@ proto_register_iso7816(void)
         },
         { &hf_iso7816_atr_next_ta_present,
             { "TA(i+1) present", "iso7816.atr.next_ta_present",
-                FT_BOOLEAN, BASE_HEX, NULL, 0x10, NULL, HFILL }
+                FT_BOOLEAN, 8, NULL, 0x10, NULL, HFILL }
         },
         { &hf_iso7816_atr_next_tb_present,
             { "TB(i+1) present", "iso7816.atr.next_tb_present",
-                FT_BOOLEAN, BASE_HEX, NULL, 0x20, NULL, HFILL }
+                FT_BOOLEAN, 8, NULL, 0x20, NULL, HFILL }
         },
         { &hf_iso7816_atr_next_tc_present,
             { "TC(i+1) present", "iso7816.atr.next_tc_present",
-                FT_BOOLEAN, BASE_HEX, NULL, 0x40, NULL, HFILL }
+                FT_BOOLEAN, 8, NULL, 0x40, NULL, HFILL }
         },
         { &hf_iso7816_atr_next_td_present,
             { "TD(i+1) present", "iso7816.atr.next_td_present",
-                FT_BOOLEAN, BASE_HEX, NULL, 0x80, NULL, HFILL }
+                FT_BOOLEAN, 8, NULL, 0x80, NULL, HFILL }
         },
         { &hf_iso7816_atr_k,
             { "Number K of historical bytes", "iso7816.atr.k",
@@ -982,8 +982,7 @@ proto_register_iso7816(void)
 
     expert_module_t* expert_iso7816;
 
-    proto_iso7816 = proto_register_protocol(
-            "ISO/IEC 7816", "ISO 7816", "iso7816");
+    proto_iso7816 = proto_register_protocol("ISO/IEC 7816", "ISO 7816", "iso7816");
     proto_register_field_array(proto_iso7816, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
     expert_iso7816 = expert_register_protocol(proto_iso7816);
@@ -1011,7 +1010,7 @@ void proto_reg_handoff_iso7816(void)
 
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
