@@ -26,11 +26,14 @@
 #include <epan/expert.h>
 #include <epan/addr_resolv.h>
 #include <epan/pci-ids.h>
+#include <epan/charsets.h>
+#include "packet-mctp.h"
 
 void proto_reg_handoff_ncsi(void);
 void proto_register_ncsi(void);
 
 static int proto_ncsi = -1;
+static dissector_handle_t ncsi_handle;
 
 /* Common header fields */
 static int hf_ncsi_mc_id = -1;
@@ -509,17 +512,13 @@ dissect_ncsi_aen(tvbuff_t *tvb, proto_tree *tree)
 #define HEXSTR(x) (((x) < 10)? '0' + (x): 'A' + ((x) - 10))
 
 static const gchar *
-ncsi_bcd_dig_to_str(tvbuff_t *tvb, const gint offset)
+ncsi_bcd_dig_to_str(wmem_allocator_t *scope, tvbuff_t *tvb, const gint offset)
 {
-    int     length = 16; /* MM.mm.uu.aa.bb */
     guint8  octet;
     int     i;
-    char   *digit_str;
+    char    digit_str[16]; /* MM.mm.uu.aa.bb */
     int     str_offset = 0;
 
-
-    digit_str = (char *)wmem_alloc(wmem_packet_scope(), length);
-
     for (i = 0 ; i < 3; i++) {
         octet = tvb_get_guint8(tvb, offset + i);
 
@@ -550,13 +549,13 @@ ncsi_bcd_dig_to_str(tvbuff_t *tvb, const gint offset)
     }
 
     digit_str[str_offset] = '\0';
-    return digit_str;
+    return get_utf_8_string(scope, digit_str, (int)strlen(digit_str));
 
 }
 
 
 static const gchar *
-ncsi_fw_version(tvbuff_t *tvb, const gint offset)
+ncsi_fw_version(wmem_allocator_t *scope, tvbuff_t *tvb, const gint offset)
 {
     int     length = 16; /* hh.hh.hh.hh */
     guint8  octet;
@@ -565,7 +564,7 @@ ncsi_fw_version(tvbuff_t *tvb, const gint offset)
     int     str_offset = 0;
 
 
-    ver_str = (char *)wmem_alloc(wmem_packet_scope(), length);
+    ver_str = (char *)wmem_alloc(scope, length);
 
     for (i = 0 ; i < 4; i++) {
         octet = tvb_get_guint8(tvb, offset + i);
@@ -905,18 +904,17 @@ dissect_ncsi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         if (plen >= 40) { /*  We got complete payload*/
             const gchar *ver_str;
             proto_tree  *ncsi_ver_tree;
-            gchar fw_name[13];
+            gchar *fw_name;
             guint16 vid, did, svid, ssid;
 
             ncsi_ver_tree = proto_tree_add_subtree(ncsi_payload_tree, tvb, 20,
                             plen - 4, ett_ncsi_payload, NULL, "Version ID");
-            ver_str = ncsi_bcd_dig_to_str(tvb, 20);
+            ver_str = ncsi_bcd_dig_to_str(pinfo->pool, tvb, 20);
             proto_tree_add_string(ncsi_ver_tree, hf_ncsi_ver, tvb, 20, 8, ver_str);
 
-            tvb_memcpy(tvb, fw_name, 28, 12);
-            fw_name[12] = 0;
+            fw_name = tvb_get_string_enc(pinfo->pool, tvb, 28, 12, ENC_ASCII);
             proto_tree_add_string(ncsi_ver_tree, hf_ncsi_fw_name, tvb, 28, 12, fw_name);
-            proto_tree_add_string(ncsi_ver_tree, hf_ncsi_fw_ver, tvb, 40, 4, ncsi_fw_version(tvb, 40));
+            proto_tree_add_string(ncsi_ver_tree, hf_ncsi_fw_ver, tvb, 40, 4, ncsi_fw_version(pinfo->pool, tvb, 40));
 
             vid = tvb_get_guint16(tvb, 46, ENC_BIG_ENDIAN);
             did = tvb_get_guint16(tvb, 44, ENC_BIG_ENDIAN);
@@ -1658,6 +1656,7 @@ proto_register_ncsi(void)
 
     /* Register the protocol name and description */
     proto_ncsi = proto_register_protocol("NCSI", "NCSI", "ncsi");
+    ncsi_handle = register_dissector("ncsi", dissect_ncsi, proto_ncsi);
 
     /* Required function calls to register the header fields and subtrees */
     proto_register_field_array(proto_ncsi, hf, array_length(hf));
@@ -1667,9 +1666,8 @@ proto_register_ncsi(void)
 void
 proto_reg_handoff_ncsi(void)
 {
-    dissector_handle_t ncsi_handle;
-    ncsi_handle = create_dissector_handle(dissect_ncsi, proto_ncsi);
     dissector_add_uint("ethertype", ETHERTYPE_NCSI, ncsi_handle);
+    dissector_add_uint("mctp.encap-type", MCTP_TYPE_NCSI, ncsi_handle);
 }
 
 /*
