@@ -3,26 +3,14 @@
  * Parser created by Henning Rogge <henning.rogge@fkie.fraunhofer.de> of Fraunhover
  * TLV values decoding by Francois Schneider <francois.schneider_@_airbus.com>
  *
- * http://tools.ietf.org/html/rfc5444
- * http://tools.ietf.org/html/rfc5498
+ * https://tools.ietf.org/html/rfc5444
+ * https://tools.ietf.org/html/rfc5498
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "config.h"
 
@@ -34,6 +22,8 @@
 void proto_reg_handoff_packetbb(void);
 void proto_register_packetbb(void);
 
+static dissector_handle_t packetbb_handle;
+
 #define PACKET_HEADER_HASSEQNR     0x08
 #define PACKET_HEADER_HASTLV       0x04
 
@@ -112,19 +102,19 @@ enum rfc7181_mpr_bitmask {
 };
 
 /* Message types defined by IANA in RFC5444 */
-const value_string msgheader_type_vals[] = {
+static const value_string msgheader_type_vals[] = {
   { 0, "HELLO (NHDP)"                   },
   { 1, "TC (OLSRv2)"                    },
   { 0, NULL                             }};
 
 /* Packet TLV types defined by IANA in RFC7182 */
-const value_string pkttlv_type_vals[] = {
+static const value_string pkttlv_type_vals[] = {
   { RFC7182_TLV_ICV              , "Integrity Check Value"         },
   { RFC7182_TLV_TIMESTAMP        , "Timestamp"                     },
   { 0                            , NULL                            }};
 
 /* Message TLV types defined by IANA in RFC5497,7181,7182 */
-const value_string msgtlv_type_vals[] = {
+static const value_string msgtlv_type_vals[] = {
   { RFC5497_TLV_INTERVAL_TIME    , "Signaling message interval"    },
   { RFC5497_TLV_VALIDITY_TIME    , "Message validity time"         },
   { RFC7182_TLV_ICV              , "Integrity Check Value"         },
@@ -134,7 +124,7 @@ const value_string msgtlv_type_vals[] = {
   { 0                            , NULL                            }};
 
 /* Address TLV types defined by IANA in RFC5497,6130,7181,7182 */
-const value_string addrtlv_type_vals[] = {
+static const value_string addrtlv_type_vals[] = {
   { RFC5497_TLV_INTERVAL_TIME    , "Signaling message interval"    },
   { RFC5497_TLV_VALIDITY_TIME    , "Message validity time"         },
   { RFC6130_ADDRTLV_LOCAL_IF     , "Local interface status"        },
@@ -149,33 +139,33 @@ const value_string addrtlv_type_vals[] = {
   { 0                            , NULL                            }};
 
 /* Values of LOCALIF TLV of RFC6130 */
-const value_string localif_vals[] = {
+static const value_string localif_vals[] = {
   { 0, "THIS_IF"                        },
   { 1, "OTHER_IF"                       },
   { 0, NULL                             }};
 
 /* Values of LINKSTATUS TLV of RFC6130 */
-const value_string linkstatus_vals[] = {
+static const value_string linkstatus_vals[] = {
   { 0, "LOST"                           },
   { 1, "SYMMETRIC"                      },
   { 2, "HEARD"                          },
   { 0, NULL                             }};
 
 /* Values of OTHERNEIGH TLV of RFC6130 */
-const value_string otherneigh_vals[] = {
+static const value_string otherneigh_vals[] = {
   { 0, "LOST"                           },
   { 1, "SYMMETRIC"                      },
   { 0, NULL                             }};
 
 /* Values of MPR TLV of RFC7181 */
-const value_string mpr_vals[] = {
+static const value_string mpr_vals[] = {
   { 1, "FLOODING"                       },
   { 2, "ROUTING"                        },
   { 3, "FLOOD_ROUTE"                    },
   { 0, NULL                             }};
 
 /* Values of NBRADDRTYPE TLV of RFC7181 */
-const value_string nbraddrtype_vals[] = {
+static const value_string nbraddrtype_vals[] = {
   { 1, "ORIGINATOR"                     },
   { 2, "ROUTABLE"                       },
   { 3, "ROUTABLE_ORIG"                  },
@@ -295,7 +285,7 @@ static proto_item* dissect_pbb_tlvvalue(tvbuff_t *tvb, proto_tree *tlvTree, guin
   proto_tree *tlv_decoded_value_tree = NULL;
   proto_tree *tlv_decoded_value_item = NULL;
 
-  static const int *mprwillingness_values[] = {
+  static int * const mprwillingness_values[] = {
     &hf_packetbb_tlv_mprwillingness_flooding,
     &hf_packetbb_tlv_mprwillingness_routing,
     NULL
@@ -376,7 +366,7 @@ static int dissect_pbb_tlvblock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
   int tlvCount = 0;
 
-  static const int *flags[] = {
+  static int * const flags[] = {
     &hf_packetbb_tlv_flags_hastypext,
     &hf_packetbb_tlv_flags_hassingleindex,
     &hf_packetbb_tlv_flags_hasmultiindex,
@@ -554,7 +544,7 @@ static int dissect_pbb_addressblock(tvbuff_t *tvb, packet_info *pinfo, proto_tre
 
   int i = 0;
 
-  static const int *flags[] = {
+  static int * const flags[] = {
     &hf_packetbb_addr_flags_hashead,
     &hf_packetbb_addr_flags_hasfulltail,
     &hf_packetbb_addr_flags_haszerotail,
@@ -716,7 +706,7 @@ static int dissect_pbb_addressblock(tvbuff_t *tvb, packet_info *pinfo, proto_tre
       case 3:
         addrValue_item = proto_tree_add_bytes_format_value(addr_tree, hf_packetbb_addr_value[addressType],
             tvb, mid_index, block_index + block_length - mid_index, NULL,
-            "%s", bytes_to_str(wmem_packet_scope(), addr, head_length + midSize));
+            "%s", bytes_to_str(pinfo->pool, addr, head_length + midSize));
         break;
       default:
         break;
@@ -899,7 +889,7 @@ static int dissect_pbb_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
   guint8 packet_flags = tvb_get_guint8(tvb, 0);
 
-  static const int *flags[] = {
+  static int * const flags[] = {
     &hf_packetbb_header_flags_phasseqnum,
     &hf_packetbb_header_flags_phastlv,
     NULL
@@ -972,9 +962,6 @@ static int dissect_packetbb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 }
 
 void proto_reg_handoff_packetbb(void) {
-  dissector_handle_t packetbb_handle;
-
-  packetbb_handle = create_dissector_handle(dissect_packetbb, proto_packetbb);
   dissector_add_uint_with_preference("udp.port", PACKETBB_PORT, packetbb_handle);
 }
 
@@ -998,12 +985,12 @@ void proto_register_packetbb(void) {
     },
     { &hf_packetbb_header_flags_phasseqnum,
       { "Has sequence number", "packetbb.flags.phasseqnum",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), PACKET_HEADER_HASSEQNR,
+        FT_BOOLEAN, 8, NULL, PACKET_HEADER_HASSEQNR,
         NULL, HFILL }
     },
     { &hf_packetbb_header_flags_phastlv,
       { "Has tlv block", "packetbb.flags.phastlv",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), PACKET_HEADER_HASTLV,
+        FT_BOOLEAN, 8, NULL, PACKET_HEADER_HASTLV,
         NULL, HFILL }
     },
     { &hf_packetbb_seqnr,
@@ -1033,22 +1020,22 @@ void proto_register_packetbb(void) {
     },
     { &hf_packetbb_msgheader_flags_mhasorig,
       { "Has originator address", "packetbb.msg.flags.mhasorig",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), MSG_HEADER_HASORIG,
+        FT_BOOLEAN, 8, NULL, MSG_HEADER_HASORIG,
         NULL, HFILL }
     },
     { &hf_packetbb_msgheader_flags_mhashoplimit,
       { "Has hoplimit", "packetbb.msg.flags.mhashoplimit",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), MSG_HEADER_HASHOPLIMIT,
+        FT_BOOLEAN, 8, NULL, MSG_HEADER_HASHOPLIMIT,
         NULL, HFILL }
     },
     { &hf_packetbb_msgheader_flags_mhashopcount,
       { "Has hopcount", "packetbb.msg.flags.mhashopcount",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), MSG_HEADER_HASHOPCOUNT,
+        FT_BOOLEAN, 8, NULL, MSG_HEADER_HASHOPCOUNT,
         NULL, HFILL }
     },
     { &hf_packetbb_msgheader_flags_mhasseqnr,
       { "Has sequence number", "packetbb.msg.flags.mhasseqnum",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), MSG_HEADER_HASSEQNR,
+        FT_BOOLEAN, 8, NULL, MSG_HEADER_HASSEQNR,
         NULL, HFILL }
     },
     { &hf_packetbb_msgheader_addresssize,
@@ -1114,27 +1101,27 @@ void proto_register_packetbb(void) {
     },
     { &hf_packetbb_addr_flags_hashead,
       { "Has head", "packetbb.msg.addr.hashead",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), ADDR_HASHEAD,
+        FT_BOOLEAN, 8, NULL, ADDR_HASHEAD,
         NULL, HFILL }
     },
     { &hf_packetbb_addr_flags_hasfulltail,
       { "Has full tail", "packetbb.msg.addr.hasfulltail",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), ADDR_HASFULLTAIL,
+        FT_BOOLEAN, 8, NULL, ADDR_HASFULLTAIL,
         NULL, HFILL }
     },
     { &hf_packetbb_addr_flags_haszerotail,
       { "Has zero tail", "packetbb.msg.addr.haszerotail",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), ADDR_HASZEROTAIL,
+        FT_BOOLEAN, 8, NULL, ADDR_HASZEROTAIL,
         NULL, HFILL }
     },
     { &hf_packetbb_addr_flags_hassingleprelen,
       { "Has single prelen", "packetbb.msg.addr.hassingleprelen",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), ADDR_HASSINGLEPRELEN,
+        FT_BOOLEAN, 8, NULL, ADDR_HASSINGLEPRELEN,
         NULL, HFILL }
     },
     { &hf_packetbb_addr_flags_hasmultiprelen,
       { "Has multiple prelen", "packetbb.msg.addr.hasmultiprelen",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), ADDR_HASMULTIPRELEN,
+        FT_BOOLEAN, 8, NULL, ADDR_HASMULTIPRELEN,
         NULL, HFILL }
     },
     { &hf_packetbb_addr_head,
@@ -1219,32 +1206,32 @@ void proto_register_packetbb(void) {
     },
     { &hf_packetbb_tlv_flags_hastypext,
       { "Has type-ext", "packetbb.tlv.hastypeext",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_TYPEEXT,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_TYPEEXT,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_flags_hassingleindex,
       { "Has single index", "packetbb.tlv.hassingleindex",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_SINGLEINDEX,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_SINGLEINDEX,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_flags_hasmultiindex,
       { "Has multiple indices", "packetbb.tlv.hasmultiindex",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_MULTIINDEX,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_MULTIINDEX,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_flags_hasvalue,
       { "Has value", "packetbb.tlv.hasvalue",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_VALUE,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_VALUE,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_flags_hasextlen,
       { "Has extended length", "packetbb.tlv.hasextlen",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_EXTLEN,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_EXTLEN,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_flags_hasmultivalue,
       { "Has multiple values", "packetbb.tlv.hasmultivalue",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), TLV_HAS_MULTIVALUE,
+        FT_BOOLEAN, 8, NULL, TLV_HAS_MULTIVALUE,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_indexstart,
@@ -1329,22 +1316,22 @@ void proto_register_packetbb(void) {
     },
     { &hf_packetbb_tlv_linkmetric_flags_linkin,
       { "Incoming link", "packetbb.tlv.linkmetriclinkin",
-        FT_BOOLEAN, 16, TFS(&tfs_true_false), RFC7181_LINKMETRIC_INCOMING_LINK,
+        FT_BOOLEAN, 16, NULL, RFC7181_LINKMETRIC_INCOMING_LINK,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_linkmetric_flags_linkout,
       { "Outgoing link", "packetbb.tlv.linkmetriclinkout",
-        FT_BOOLEAN, 16, TFS(&tfs_true_false), RFC7181_LINKMETRIC_OUTGOING_LINK,
+        FT_BOOLEAN, 16, NULL, RFC7181_LINKMETRIC_OUTGOING_LINK,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_linkmetric_flags_neighin,
       { "Incoming neighbor", "packetbb.tlv.linkmetricneighin",
-        FT_BOOLEAN, 16, TFS(&tfs_true_false), RFC7181_LINKMETRIC_INCOMING_NEIGH,
+        FT_BOOLEAN, 16, NULL, RFC7181_LINKMETRIC_INCOMING_NEIGH,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_linkmetric_flags_neighout,
       { "Outgoing neighbor", "packetbb.tlv.linkmetricneighout",
-        FT_BOOLEAN, 16, TFS(&tfs_true_false), RFC7181_LINKMETRIC_OUTGOING_NEIGH,
+        FT_BOOLEAN, 16, NULL, RFC7181_LINKMETRIC_OUTGOING_NEIGH,
         NULL, HFILL }
     },
     { &hf_packetbb_tlv_linkmetric_value,
@@ -1406,6 +1393,7 @@ void proto_register_packetbb(void) {
 
   /* name, short name, abbrev */
   proto_packetbb = proto_register_protocol("PacketBB Protocol", "PacketBB", "packetbb");
+  packetbb_handle = register_dissector("packetbb", dissect_packetbb, proto_packetbb);
 
   /* Required function calls to register the header fields and subtrees used */
   proto_register_field_array(proto_packetbb, hf, array_length(hf));
@@ -1415,7 +1403,7 @@ void proto_register_packetbb(void) {
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local Variables:
  * c-basic-offset: 2
