@@ -25,7 +25,7 @@
 #include <wsutil/filesystem.h>
 #include <epan/prefs.h>
 #include <epan/expert.h>
-#include <epan/garrayfix.h>
+#include <epan/iana_charsets.h>
 #include <wsutil/str_util.h>
 #include <wsutil/report_message.h>
 
@@ -71,6 +71,7 @@ static xml_ns_t unknown_ns = {"unknown", "?", -1, -1, -1, NULL, NULL, NULL};
 static xml_ns_t *root_ns;
 
 static gboolean pref_heuristic_unicode    = FALSE;
+static gint pref_default_encoding = IANA_CS_UTF_8;
 
 
 #define XML_CDATA       -1000
@@ -79,6 +80,7 @@ static gboolean pref_heuristic_unicode    = FALSE;
 
 static wmem_array_t *hf_arr;
 static GArray *ett_arr;
+static GRegex* encoding_pattern;
 
 static const gchar *default_media_types[] = {
     "text/xml",
@@ -174,7 +176,33 @@ static const gchar *default_media_types[] = {
     "application/vnd.3gpp.cw+xml",
     "application/vnd.3gpp.iut+xml",             /*3GPP TS 24.337*/
     "application/vnc.3gpp.iut-config+xml",      /*3GPP TS 24.337*/
-    "application/vnd.3gpp.mcptt-info+xml",
+    "application/vnd.3gpp.mcptt-info+xml",                 /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-mbms-usage-info+xml",      /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-location-info+xml",        /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-affiliation-command+xml",  /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-floor-request+xml",        /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-signed+xml",               /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-regroup+xml",              /*3GPP TS 24.379 version 17.6.0*/
+    "application/vnd.3gpp.mcdata-info+xml",                /*3GPP TS 24.282 version 17.6.2*/
+    "application/vnd.3gpp.mcdata-mbms-usage-info+xml",     /*3GPP TS 24.282 version 17.6.2*/
+    "application/vnd.3gpp.mcdata-location-info+xml",       /*3GPP TS 24.282 version 17.6.2*/
+    "application/vnd.3gpp.mcdata-affiliation-command+xml", /*3GPP TS 24.282 version 17.6.2*/
+    "application/vnd.3gpp.mcdata-regroup+xml",             /*3GPP TS 24.282 version 17.6.2*/
+    "application/vnd.3gpp.mcvideo-info+xml",               /*3GPP TS 24.281 version 17.6.0*/
+    "application/vnd.3gpp.mcvideo-mbms-usage-info+xml",    /*3GPP TS 24.281 version 17.6.0*/
+    "application/vnd.3gpp.mcvideo-location-info+xml",      /*3GPP TS 24.281 version 17.6.0*/
+    "application/vnd.3gpp.mcvideo-affiliation-command+xml",/*3GPP TS 24.281 version 17.6.0*/
+    "application/vnd.3gpp.transmission-request+xml",       /*3GPP TS 24.281 version 17.6.0*/
+    "application/vnd.3gpp.mcptt-ue-init-config+xml",       /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcptt-ue-config+xml",            /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcptt-user-profile+xml",         /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcptt-service-config+xml",       /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcdata-service-config+xml",      /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcvideo-service-config+xml",     /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcvideo-ue-config+xml",          /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcvideo-user-profile+xml",       /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcdata-ue-config+xml",           /*3GPP TS 24.484 version 17.5.0*/
+    "application/vnd.3gpp.mcdata-user-profile+xml",        /*3GPP TS 24.484 version 17.5.0*/
     "application/vnd.3gpp.mid-call+xml",
     "application/vnd.3gpp-prose-pc3ch+xml",
     "application/vnd.3gpp-prose+xml",
@@ -225,6 +253,47 @@ static void insert_xml_frame(xml_frame_t *parent, xml_frame_t *new_child)
     parent->last_child = new_child;
 }
 
+/* Try to get the 'encoding' attribute from XML declaration, and convert it to
+ * Wireshark character encoding.
+ */
+static guint
+get_char_encoding(tvbuff_t* tvb, packet_info* pinfo, gchar** ret_encoding_name) {
+    guint32 iana_charset_id;
+    guint ws_encoding_id;
+    gchar* encoding_str;
+    GMatchInfo* match_info;
+    const gchar* xmldecl = (gchar*)tvb_get_string_enc(pinfo->pool, tvb, 0,
+        MIN(100, tvb_captured_length(tvb)), ENC_UTF_8);
+
+    g_regex_match(encoding_pattern, xmldecl, 0, &match_info);
+    if (g_match_info_matches(match_info)) {
+        gchar* match_ret = g_match_info_fetch(match_info, 1);
+        encoding_str = ascii_strup_inplace(wmem_strdup(pinfo->pool, match_ret));
+        g_free(match_ret);
+        /* Get the iana charset enum number by the name of the charset. */
+        iana_charset_id = str_to_val(encoding_str,
+            VALUE_STRING_EXT_VS_P(&mibenum_vals_character_sets_ext), IANA_CS_US_ASCII);
+    } else {
+        /* Use default encoding preference if this xml does not contains 'encoding' attribute. */
+        iana_charset_id = pref_default_encoding;
+        encoding_str = val_to_str_ext_wmem(pinfo->pool, iana_charset_id,
+            &mibenum_vals_character_sets_ext, "UNKNOWN");
+    }
+    g_match_info_free(match_info);
+
+    ws_encoding_id = mibenum_charset_to_encoding((guint)iana_charset_id);
+
+    /* UTF-8 compatible with ASCII */
+    if (ws_encoding_id == (ENC_NA | ENC_ASCII)) {
+        ws_encoding_id = ENC_UTF_8;
+        *ret_encoding_name = wmem_strdup(pinfo->pool, "UTF-8");
+    } else {
+        *ret_encoding_name = encoding_str;
+    }
+
+    return ws_encoding_id;
+}
+
 static int
 dissect_xml(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
@@ -266,8 +335,15 @@ dissect_xml(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     }
     /* Could also test if try_bom is 0xnn00 or 0x00nn to guess endianness if we wanted */
     else {
-        /* Assume it's UTF-8, either with or without BOM */
-        decoded = tvb;
+        /* Get character encoding according to XML declaration or preference. */
+        gchar* encoding_name;
+        guint encoding = get_char_encoding(tvb, pinfo, &encoding_name);
+
+        /* Encoding string with encoding, either with or without BOM */
+        const guint8 *data_str = tvb_get_string_enc(pinfo->pool, tvb, 0, tvb_captured_length(tvb), encoding);
+        size_t l = strlen(data_str);
+        decoded = tvb_new_child_real_data(tvb, data_str, (guint)l, (gint)l);
+        add_new_data_source(pinfo, decoded, wmem_strdup_printf(pinfo->pool, "Decoded %s text", encoding_name));
     }
 
     tt = tvbparse_init(pinfo->pool, decoded, 0, -1, stack, want_ignore);
@@ -299,7 +375,7 @@ dissect_xml(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
     while(tvbparse_get(tt, want)) ;
 
-    /* Save XML structure in case it is useful for the caller (only XMPP for now) */
+    /* Save XML structure in case it is useful for the caller */
     p_add_proto_data(pinfo->pool, pinfo, xml_ns.hf_tag, 0, current_frame);
 
     return tvb_captured_length(tvb);
@@ -618,7 +694,7 @@ static void before_dtd_doctype(void *tvbparse_data, const void *wanted_data _U_,
     tvbparse_elem_t *name_tok      = tok->sub->next->next->next->sub->sub;
     proto_tree      *dtd_item      = proto_tree_add_item(current_frame->tree, hf_doctype,
                                                          name_tok->tvb, name_tok->offset,
-                                                         name_tok->len, ENC_ASCII|ENC_NA);
+                                                         name_tok->len, ENC_ASCII);
 
     proto_item_set_text(dtd_item, "%s", tvb_format_text(wmem_packet_scope(), tok->tvb, tok->offset, tok->len));
 
@@ -1043,7 +1119,6 @@ static gchar *fully_qualified_name(GPtrArray *hier, gchar *name, gchar *proto_na
 }
 
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static xml_ns_t *make_xml_hier(gchar      *elem_name,
                                xml_ns_t   *root,
                                wmem_map_t *elements,
@@ -1070,11 +1145,6 @@ static xml_ns_t *make_xml_hier(gchar      *elem_name,
         return NULL;
     }
 
-    if (hier->len >= prefs.gui_max_tree_depth) {
-        g_string_append_printf(error, "hierarchy too deep: %u\n", hier->len);
-        return NULL;
-    }
-
     for (i = 0; i < hier->len; i++) {
         if( (elem_name) && (strcmp(elem_name, (gchar *) g_ptr_array_index(hier, i) ) == 0 )) {
             recurred = TRUE;
@@ -1327,7 +1397,7 @@ static void register_dtd(dtd_build_data_t *dtd_data, GString *errors)
 
         root_element->hf_tag = proto_register_protocol(full_name, short_name, short_name);
         proto_register_field_array(root_element->hf_tag, (hf_register_info*)wmem_array_get_raw(hfs), wmem_array_get_count(hfs));
-        proto_register_subtree_array((gint **)g_array_data(etts), etts->len);
+        proto_register_subtree_array((gint **)etts->data, etts->len);
 
         if (dtd_data->media_type) {
             gchar* media_type = wmem_strdup(wmem_epan_scope(), dtd_data->media_type);
@@ -1439,6 +1509,17 @@ static void init_xml_names(void)
     wmem_free(wmem_epan_scope(), dummy);
 }
 
+static void
+xml_init_protocol(void)
+{
+    encoding_pattern = g_regex_new("^<[?]xml\\s+version\\s*=\\s*[\"']\\s*.+\\s*[\"']\\s+encoding\\s*=\\s*[\"']\\s*(.+)\\s*[\"']", G_REGEX_CASELESS, 0, 0);
+}
+
+static void
+xml_cleanup_protocol(void) {
+    g_regex_unref(encoding_pattern);
+}
+
 void
 proto_register_xml(void)
 {
@@ -1517,7 +1598,7 @@ proto_register_xml(void)
     xml_ns.hf_tag = proto_register_protocol("eXtensible Markup Language", "XML", xml_ns.name);
 
     proto_register_field_array(xml_ns.hf_tag, (hf_register_info*)wmem_array_get_raw(hf_arr), wmem_array_get_count(hf_arr));
-    proto_register_subtree_array((gint **)g_array_data(ett_arr), ett_arr->len);
+    proto_register_subtree_array((gint **)ett_arr->data, ett_arr->len);
     expert_xml = expert_register_protocol(xml_ns.hf_tag);
     expert_register_field_array(expert_xml, ei, array_length(ei));
 
@@ -1530,8 +1611,16 @@ proto_register_xml(void)
                                    "Try to recognize XML encoded in Unicode (UCS-2BE)",
                                    &pref_heuristic_unicode);
 
+    prefs_register_enum_preference(xml_module, "default_encoding", "Default character encoding",
+                                   "Use this charset if the 'encoding' attribute of XML declaration is missing."
+                                   "Unsupported encoding will be replaced by the default UTF-8.",
+                                   &pref_default_encoding, ws_supported_mibenum_vals_character_sets_ev_array, FALSE);
+
     g_array_free(ett_arr, TRUE);
 
+    register_init_routine(&xml_init_protocol);
+    register_cleanup_routine(&xml_cleanup_protocol);
+
     xml_handle = register_dissector("xml", dissect_xml, xml_ns.hf_tag);
 
     init_xml_parser();
