@@ -15,6 +15,8 @@
 
 #include "mate.h"
 #include "mate_util.h"
+
+#include <errno.h>
 #include <wsutil/file_util.h>
 
 
@@ -38,7 +40,7 @@ void dbg_print(const gint* which, gint how, FILE* where, const gchar* fmt, ... )
 	if ( ! which || *which < how ) return;
 
 	va_start( list, fmt );
-	g_vsnprintf(debug_buffer,DEBUG_BUFFER_SIZE,fmt,list);
+	vsnprintf(debug_buffer,DEBUG_BUFFER_SIZE,fmt,list);
 	va_end( list );
 
 	if (! where) {
@@ -193,7 +195,7 @@ gchar* scs_subscribe_printf(SCS_collection* c, gchar* fmt, ...) {
 	static gchar buf[SCS_HUGE_SIZE];
 
 	va_start( list, fmt );
-	g_vsnprintf(buf, SCS_HUGE_SIZE, fmt, list);
+	vsnprintf(buf, SCS_HUGE_SIZE, fmt, list);
 	va_end( list );
 
 	return scs_subscribe(c,buf);
@@ -293,7 +295,7 @@ extern AVP* new_avp_from_finfo(const gchar* name, field_info* finfo) {
 
 	new_avp_val->n = scs_subscribe(avp_strings, name);
 
-	repr = fvalue_to_string_repr(NULL, &finfo->value,FTREPR_DISPLAY,finfo->hfinfo->display);
+	repr = fvalue_to_string_repr(NULL, finfo->value, FTREPR_DISPLAY, finfo->hfinfo->display);
 
 	if (repr) {
 		value = scs_subscribe(avp_strings, repr);
@@ -1435,13 +1437,13 @@ static LoAL* load_loal_error(FILE* fp, LoAL* loal, AVPL* curr, int linenum, cons
 	gchar* err;
 
 	va_start( list, fmt );
-	desc = g_strdup_vprintf(fmt, list);
+	desc = ws_strdup_vprintf(fmt, list);
 	va_end( list );
 
 	if (loal) {
-		err = g_strdup_printf("Error Loading LoAL from file: in %s at line: %i, %s",loal->name,linenum,desc);
+		err = ws_strdup_printf("Error Loading LoAL from file: in %s at line: %i, %s",loal->name,linenum,desc);
 	} else {
-		err = g_strdup_printf("Error Loading LoAL at line: %i, %s",linenum,desc);
+		err = ws_strdup_printf("Error Loading LoAL at line: %i, %s",linenum,desc);
 	}
 	ret = new_loal(err);
 
@@ -1559,7 +1561,7 @@ extern LoAL* loal_from_file(gchar* filename) {
 							i = 0;
 							name[i++] = c;
 							name[i] = '\0';
-							g_snprintf(linenum_buf,MAX_ITEM_LEN,"%s:%u",filename,linenum);
+							snprintf(linenum_buf,MAX_ITEM_LEN,"%s:%u",filename,linenum);
 							curr = new_avpl(linenum_buf);
 							continue;
 						case '#':
