@@ -60,7 +60,8 @@ def program_path(request):
     '''
     curdir_run = os.path.join(os.curdir, 'run')
     if sys.platform == 'win32':
-        curdir_run_config = os.path.join(curdir_run, 'RelWithDebInfo')
+        build_type = request.config.getoption('--build-type')
+        curdir_run_config = os.path.join(curdir_run, build_type)
         if os.path.exists(curdir_run_config):
             curdir_run = curdir_run_config
     paths = (
