@@ -14,10 +14,20 @@ class TestDfilterSyntax:
         checkDFilterCount(dfilter, 1)
 
     def test_exists_2(self, checkDFilterCount):
-        # Identifier using minus
+        # Protocol using minus
         dfilter = "mac-lte"
         checkDFilterCount(dfilter, 0)
 
+    def test_exists_3(self, checkDFilterCount):
+        # Protocol starting with digit
+        dfilter = "9p or http"
+        checkDFilterCount(dfilter, 1)
+
+    def test_exists_4(self, checkDFilterCount):
+        # Protocol with dot
+        dfilter = "_ws.expert"
+        checkDFilterCount(dfilter, 1)
+
     def test_commute_1(self, checkDFilterCount):
         dfilter = "ip.proto == 6"
         checkDFilterCount(dfilter, 1)
@@ -432,3 +442,31 @@ class TestDfilterXor:
     def test_xor_4(self, checkDFilterCount):
         dfilter = 'ip.src == 9.9.9.9 ^^ ip.dst == 9.9.9.9'
         checkDFilterCount(dfilter, 0)
+
+class TestDfilterTFSValueString:
+    trace_file = "http.pcap"
+
+    def test_tfs_1(self, checkDFilterCount):
+        dfilter = 'ip.flags.df == True'
+        checkDFilterCount(dfilter, 1)
+
+    def test_tfs_2(self, checkDFilterCount):
+        dfilter = 'ip.flags.df == "True"'
+        checkDFilterCount(dfilter, 1)
+
+    def test_tfs_3(self, checkDFilterCount):
+        dfilter = 'ip.flags.df == "Set"'
+        checkDFilterCount(dfilter, 1)
+
+    def test_tfs_4(self, checkDFilterCount):
+        dfilter = 'frame.ignored == False'
+        checkDFilterCount(dfilter, 1)
+
+    def test_tfs_5(self, checkDFilterCount):
+        dfilter = 'frame.ignored == "False"'
+        checkDFilterCount(dfilter, 1)
+
+    def test_tfs_6(self, checkDFilterFail):
+        error = 'expected "True" or "False", not "Unset"'
+        dfilter = 'frame.ignored == "Unset"'
+        checkDFilterFail(dfilter, error)
