@@ -11,14 +11,8 @@ import argparse
 import signal
 import subprocess
 
-# This utility scans the dissector code for proto_tree_add_...() calls that constrain the type
-# or length of the item added, and checks that the used item is acceptable.
-#
-# - Note that this can only work where the hf_item variable or length is passed in directly - simple
-#   macro substitution is now done in a limited way 
-
+# This utility scans the dissector code for various issues.
 # TODO:
-# - Attempt to check for allowed encoding types (most likely will be literal values |'d)?
 # - Create maps from type -> display types for hf items (see display (FIELDDISPLAY)) in docs/README.dissector
 
 
@@ -43,7 +37,7 @@ def name_has_one_of(name, substring_list):
     return False
 
 # A call is an individual call to an API we are interested in.
-# Internal to APICheck below.
+# Used by APICheck below.
 class Call:
     def __init__(self, hf_name, macros, line_number=None, length=None, fields=None):
         self.hf_name = hf_name
@@ -234,7 +228,7 @@ class APICheck:
                     warnings_found += 1
 
 
-
+# Specialization of APICheck for add_item() calls
 class ProtoTreeAddItemCheck(APICheck):
     def __init__(self, ptv=None):
 
@@ -372,7 +366,8 @@ known_non_contiguous_fields = { 'wlan.fixed.capabilities.cfpoll.sta',
                                 'xmcp.type.class',
                                 'xmcp.type.method',
                                 'hf_hiqnet_flags',
-                                'hf_hiqnet_flagmask'
+                                'hf_hiqnet_flagmask',
+                                'hf_h223_mux_mpl'
                               }
 ##################################################################################################
 
@@ -398,6 +393,7 @@ field_widths = {
     'FT_INT64'   : 64
 }
 
+# TODO: most of these might as well be strings...
 def is_ignored_consecutive_filter(filter):
     ignore_patterns = [
         re.compile(r'^elf.sh_type'),
@@ -516,8 +512,6 @@ class ValueString:
         self.min_value =  99999
         self.max_value = -99999
 
-        #print('ValueString', name)
-
         # Now parse out each entry in the value_string
         matches = re.finditer(r'\{\s*([0-9_A-Za-z]*)\s*,\s*(".*?")\s*}\s*,', self.raw_vals)
         for m in matches:
@@ -549,15 +543,16 @@ class ValueString:
                     self.parsed_vals[value], 'now', label)
                 warnings_found += 1
             else:
-                # Add into table
+                # Add into table, while checking for repeated label
                 self.parsed_vals[value] = label
                 if do_extra_checks and label in self.seen_labels:
+                    # These are commonly repeated..
                     exceptions = [ 'reserved', 'invalid', 'unused', 'not used', 'unknown', 'undefined', 'spare',
                                    'unallocated', 'not assigned', 'implementation specific', 'unspecified',
                                    'other', 'for further study', 'future', 'vendor specific', 'obsolete', 'none',
                                    'shall not be used', 'national use', 'unassigned', 'oem', 'user defined',
                                    'manufacturer specific', 'not specified', 'proprietary', 'operator-defined',
-                                   'dynamically allocated', 'user specified' ]
+                                   'dynamically allocated', 'user specified', 'xxx', 'default', 'planned', 'not req' ]
                     excepted = False
                     for ex in exceptions:
                         if label.lower().find(ex) != -1:
@@ -589,8 +584,41 @@ class ValueString:
                     global warnings_found
                     warnings_found += 1
 
-        # Look for repeated labels
-        #for val in self.parsed_vals:
+        # Do most of the labels match the number?
+        matching_label_entries = set()
+        for val in self.parsed_vals:
+            if self.parsed_vals[val].find(str(val)) != -1:
+                # TODO: pick out multiple values rather than concat into wrong number
+                parsed_value = int(''.join(d for d in self.parsed_vals[val] if d.isdecimal()))
+                if val == parsed_value:
+                    matching_label_entries.add(val)
+
+        if len(matching_label_entries) >= 4 and len(matching_label_entries) > 0 and len(matching_label_entries) < num_items and len(matching_label_entries) >= num_items-1:
+            # Be forgiving about first or last entry
+            first_val = list(self.parsed_vals)[0]
+            last_val =  list(self.parsed_vals)[-1]
+            if not first_val in matching_label_entries or not last_val in matching_label_entries:
+                return
+            print('Warning:', self.file, ': value_string', self.name, 'Labels match value except for 1!', matching_label_entries, num_items, self)
+
+        # Do all labels start with lower-or-upper char?
+        startLower,startUpper = 0,0
+        for val in self.parsed_vals:
+            first_letter = self.parsed_vals[val][1]
+            if first_letter.isalpha():
+                if first_letter.isupper():
+                    startUpper += 1
+                else:
+                    startLower += 1
+        if startLower > 0 and startUpper > 0:
+            if startLower+startUpper > 10 and (startLower <=3 or startUpper <=3):
+                standouts = []
+                if startLower < startUpper:
+                    standouts += [self.parsed_vals[val] for val in self.parsed_vals if self.parsed_vals[val][1].islower()]
+                if startLower > startUpper:
+                    standouts += [self.parsed_vals[val] for val in self.parsed_vals if self.parsed_vals[val][1].isupper()]
+
+                print('Note:', self.file, ': value_string', self.name, 'mix of upper', startUpper, 'and lower', startLower, standouts)
 
 
     def __str__(self):
@@ -627,14 +655,15 @@ class Item:
 
     previousItem = None
 
-    def __init__(self, filename, hf, filter, label, item_type, type_modifier, macros, mask=None,
-                 check_mask=False, mask_exact_width=False, check_label=False, check_consecutive=False):
+    def __init__(self, filename, hf, filter, label, item_type, display, strings, macros, value_strings,
+                 mask=None, check_mask=False, mask_exact_width=False, check_label=False,
+                 check_consecutive=False, blurb=''):
         self.filename = filename
         self.hf = hf
         self.filter = filter
         self.label = label
-
         self.mask = mask
+        self.strings = strings
         self.mask_exact_width = mask_exact_width
 
         global warnings_found
@@ -651,38 +680,66 @@ class Item:
 
             Item.previousItem = self
 
-
-        # Optionally check label.
-        if check_label:
-            if label.startswith(' ') or label.endswith(' '):
-                print('Warning: ' + filename, hf, 'filter "' + filter +  '" label' + label + '" begins or ends with a space')
-                warnings_found += 1
-
-            if (label.count('(') != label.count(')') or
-                label.count('[') != label.count(']') or
-                label.count('{') != label.count('}')):
-                # Ignore if includes quotes, as may be unbalanced.
-                if label.find("'") == -1:
-                    print('Warning: ' + filename, hf, 'filter "' + filter + '" label', '"' + label + '"', 'has unbalanced parens/braces/brackets')
-                    warnings_found += 1
-            if item_type != 'FT_NONE' and label.endswith(':'):
-                print('Warning: ' + filename, hf, 'filter "' + filter + '" label', '"' + label + '"', 'ends with an unnecessary colon')
-                warnings_found += 1
-
         self.item_type = item_type
-        self.type_modifier = type_modifier
+        self.display = display
+
+        # Optionally check label (short and long).
+        if check_label:
+            self.check_label(label, 'label')
+            #self.check_label(blurb, 'blurb')
 
         # Optionally check that mask bits are contiguous
         if check_mask:
-            if self.mask_read and not mask in { 'NULL', '0x0', '0', '0x00'}:
+            if self.mask_read and not mask in { 'NULL', '0x0', '0', '0x00' }:
                 self.check_contiguous_bits(mask)
                 self.check_num_digits(self.mask)
+                # N.B., if last entry in set is removed, see around 18,000 warnings
                 self.check_digits_all_zeros(self.mask)
 
+        # N.B. these checks are already done by checkApis.pl
+        if strings.find('RVALS') != -1 and display.find('BASE_RANGE_STRING') == -1:
+            print('Warning: ' + filename, hf, 'filter "' + filter + ' strings has RVALS but display lacks BASE_RANGE_STRING')
+            warnings_found += 1
+
+        # For RVALS, is BASE_RANGE_STRING also set (checked by checkApis.pl)?
+        if strings.find('VALS_EXT_PTR') != -1 and display.find('BASE_EXT_STRING') == -1:
+            print('Warning: ' + filename, hf, 'filter "' + filter + ' strings has VALS_EXT_PTR but display lacks BASE_EXT_STRING')
+            warnings_found += 1
+
+        # For VALS, lookup the corresponding ValueString and try to check range.
+        vs_re = re.compile(r'VALS\(([a-zA-Z0-9_]*)\)')
+        m = vs_re.search(strings)
+        if m:
+            self.vs_name = m.group(1)
+            if self.vs_name in value_strings:
+                vs = value_strings[self.vs_name]
+                self.check_value_string_range(vs.min_value, vs.max_value)
+
 
     def __str__(self):
-        return 'Item ({0} "{1}" {2} type={3}:{4} mask={5})'.format(self.filename, self.label, self.filter, self.item_type, self.type_modifier, self.mask)
+        return 'Item ({0} "{1}" {2} type={3}:{4} {5} mask={6})'.format(self.filename, self.label, self.filter, self.item_type, self.display, self.strings, self.mask)
 
+    def check_label(self, label, label_name):
+        global warnings_found
+
+        # TODO: this is masking a bug where the re for the item can't cope with macro for containing ',' for mask arg..
+        if label.count('"') == 1:
+            return
+
+        if label.startswith(' ') or label.endswith(' '):
+            print('Warning: ' + self.filename, self.hf, 'filter "' + self.filter, label_name,  '"' + label + '" begins or ends with a space')
+            warnings_found += 1
+
+        if (label.count('(') != label.count(')') or
+            label.count('[') != label.count(']') or
+            label.count('{') != label.count('}')):
+            # Ignore if includes quotes, as may be unbalanced.
+            if label.find("'") == -1:
+                print('Warning: ' + self.filename, self.hf, 'filter "' + self.filter + '"', label_name, '"' + label + '"', 'has unbalanced parens/braces/brackets')
+                warnings_found += 1
+        if self.item_type != 'FT_NONE' and label.endswith(':'):
+            print('Warning: ' + self.filename, self.hf, 'filter "' + self.filter + '"', label_name, '"' + label + '"', 'ends with an unnecessary colon')
+            warnings_found += 1
 
 
     def set_mask_value(self, macros):
@@ -709,6 +766,25 @@ class Item:
             self.mask_read = False
             self.mask_value = 0
 
+    def check_value_string_range(self, vs_min, vs_max):
+        # N,B, this doesn't reduce bit count when a mask is set!
+        item_width = self.get_field_width_in_bits()
+        if self.mask_value > 0:
+            # Have mask, so count number of bits set.
+            item_width = 0
+            for n in range(0,63):
+                item_width += 1 if self.check_bit(self.mask_value, n) else 0
+
+        if item_width is None:
+            # Type field defined by macro?
+            return
+        item_max = (2 ** item_width) - 1
+        if vs_max > item_max:
+            global warnings_found
+            print('Warning:', self.filename, self.hf, 'filter=', self.filter,
+                  self.strings, "has max value", vs_max, '(' + hex(vs_max) + ')', "which doesn't fit into", item_width, 'bits',
+                  '( mask is', hex(self.mask_value), ')')
+            warnings_found += 1
 
     # Return true if bit position n is set in value.
     def check_bit(self, value, n):
@@ -717,7 +793,7 @@ class Item:
     # Output a warning if non-contigous bits are found in the mask (guint64).
     # Note that this legimately happens in several dissectors where multiple reserved/unassigned
     # bits are conflated into one field.
-    # TODO: there is probably a cool/efficient way to check this?
+    # TODO: there is probably a cool/efficient way to check this (+1 => 1-bit set?)
     def check_contiguous_bits(self, mask):
         if not self.mask_value:
             return
@@ -777,16 +853,16 @@ class Item:
 
     def get_field_width_in_bits(self):
         if self.item_type == 'FT_BOOLEAN':
-            if self.type_modifier == 'NULL':
+            if self.display == 'NULL':
                 return 8  # i.e. 1 byte
-            elif self.type_modifier == 'BASE_NONE':
+            elif self.display == 'BASE_NONE':
                 return 8
-            elif self.type_modifier == 'SEP_DOT':   # from proto.h, only meant for FT_BYTES
+            elif self.display == 'SEP_DOT':   # from proto.h, only meant for FT_BYTES
                 return 64
             else:
                 try:
                     # For FT_BOOLEAN, modifier is just numerical number of bits. Round up to next nibble.
-                    return int((int(self.type_modifier) + 3)/4)*4
+                    return int((int(self.display) + 3)/4)*4
                 except:
                     return None
         else:
@@ -800,38 +876,39 @@ class Item:
         if mask.startswith('0x') and len(mask) > 3:
             global warnings_found
             global errors_found
-            # Warn if odd number of digits/  TODO: only if >= 5?
+
+            width_in_bits = self.get_field_width_in_bits()
+            # Warn if odd number of digits.  TODO: only if >= 5?
             if len(mask) % 2  and self.item_type != 'FT_BOOLEAN':
                 print('Warning:', self.filename, self.hf, 'filter=', self.filter, ' - mask has odd number of digits', mask,
-                      'expected max for', self.item_type, 'is', int((self.get_field_width_in_bits())/4))
+                      'expected max for', self.item_type, 'is', int(width_in_bits/4))
                 warnings_found += 1
 
             if self.item_type in field_widths:
                 # Longer than it should be?
-                width_in_bits = self.get_field_width_in_bits()
                 if width_in_bits is None:
                     return
                 if len(mask)-2 > width_in_bits/4:
-                    extra_digits = mask[2:2+(len(mask)-2 - int(self.get_field_width_in_bits()/4))]
+                    extra_digits = mask[2:2+(len(mask)-2 - int(width_in_bits/4))]
                     # Its definitely an error if any of these are non-zero, as they won't have any effect!
                     if extra_digits != '0'*len(extra_digits):
                         print('Error:', self.filename, self.hf, 'filter=', self.filter, 'mask', self.mask, "with len is", len(mask)-2,
-                              "but type", self.item_type, " indicates max of", int(self.get_field_width_in_bits()/4),
+                              "but type", self.item_type, " indicates max of", int(width_in_bits/4),
                               "and extra digits are non-zero (" + extra_digits + ")")
                         errors_found += 1
                     else:
                         # Has extra leading zeros, still confusing, so warn.
                         print('Warning:', self.filename, self.hf, 'filter=', self.filter, 'mask', self.mask, "with len", len(mask)-2,
-                              "but type", self.item_type, " indicates max of", int(self.get_field_width_in_bits()/4))
+                              "but type", self.item_type, " indicates max of", int(width_in_bits/4))
                         warnings_found += 1
 
                 # Strict/fussy check - expecting mask length to match field width exactly!
                 # Currently only doing for FT_BOOLEAN, and don't expect to be in full for 64-bit fields!
                 if self.mask_exact_width:
-                    ideal_mask_width = int(self.get_field_width_in_bits()/4)
+                    ideal_mask_width = int(width_in_bits/4)
                     if self.item_type == 'FT_BOOLEAN' and ideal_mask_width < 16 and len(mask)-2 != ideal_mask_width:
                         print('Warning:', self.filename, self.hf, 'filter=', self.filter, 'mask', self.mask, "with len", len(mask)-2,
-                                "but type", self.item_type, "|", self.type_modifier,  " indicates should be", int(self.get_field_width_in_bits()/4))
+                                "but type", self.item_type, "|", self.display,  " indicates should be", int(width_in_bits/4))
                         warnings_found += 1
 
             else:
@@ -893,6 +970,7 @@ class Item:
         label = label.replace('(', '')
         label = label.replace(')', '')
         label = label.replace('/', '')
+        label = label.replace("'", '')
 
 
         # OK if filter is abbrev of label.
@@ -910,9 +988,8 @@ class Item:
         filter_numbers = [int(n) for n in re.findall(r'\d+', last_filter_orig)]
         if len(label_numbers) == len(filter_numbers) and label_numbers != filter_numbers:
             if reportNumericalMismatch:
-                print('Warning:', self.filename, self.hf, 'label="' + self.label + '" has different **numbers** from  filter="' + self.filter + '"')
+                print('Note:', self.filename, self.hf, 'label="' + self.label + '" has different **numbers** from  filter="' + self.filter + '"')
                 print(label_numbers, filter_numbers)
-                warnings_found += 1
             return False
 
         # If they match after trimming number from filter, they should match.
@@ -1118,7 +1195,8 @@ def find_macros(filename):
 
 
 # Look for hf items (i.e. full item to be registered) in a dissector file.
-def find_items(filename, macros, check_mask=False, mask_exact_width=False, check_label=False, check_consecutive=False):
+def find_items(filename, macros, value_strings,
+               check_mask=False, mask_exact_width=False, check_label=False, check_consecutive=False):
     is_generated = isGeneratedFile(filename)
     items = {}
     with open(filename, 'r', encoding="utf8") as f:
@@ -1127,14 +1205,24 @@ def find_items(filename, macros, check_mask=False, mask_exact_width=False, check
         contents = removeComments(contents)
 
         # N.B. re extends all the way to HFILL to avoid greedy matching
+        # TODO: fix a problem where re can't cope with mask that involve a macro with commas in it...
         matches = re.finditer( r'.*\{\s*\&(hf_[a-z_A-Z0-9]*)\s*,\s*{\s*\"(.*?)\"\s*,\s*\"(.*?)\"\s*,\s*(.*?)\s*,\s*([0-9A-Z_\|\s]*?)\s*,\s*(.*?)\s*,\s*(.*?)\s*,\s*([a-zA-Z0-9\W\s_\u00f6\u00e4]*?)\s*,\s*HFILL', contents)
+        #matches = re.finditer( r'.*\{\s*\&(hf_[a-z_A-Z0-9]*)\s*,\s*{\s*\"(.*?)\"\s*,\s*\"(.*?)\"\s*,\s*(.*?)\s*,\s*([0-9A-Z_\|\s]*?)\s*,\s*(.*?)\s*,\s*(.*?)\s*,\s*(NULL|"[a-zA-Z0-9\W\s_/\u00f6\u00e4]*?")\s*,\s*HFILL', contents)
         for m in matches:
             # Store this item.
             hf = m.group(1)
+
+            blurb = m.group(8)
+            if blurb.startswith('"'):
+                blurb = blurb[1:-1]
+
             items[hf] = Item(filename, hf, filter=m.group(3), label=m.group(2), item_type=m.group(4),
-                             type_modifier=m.group(5),
+                             display=m.group(5),
+                             strings=m.group(6),
                              macros=macros,
+                             value_strings=value_strings,
                              mask=m.group(7),
+                             blurb=blurb,
                              check_mask=check_mask,
                              mask_exact_width=mask_exact_width,
                              check_label=check_label,
@@ -1270,8 +1358,16 @@ def checkFile(filename, check_mask=False, mask_exact_width=False, check_label=Fa
     # Find simple macros so can substitute into items and calls.
     macros = find_macros(filename)
 
+    # Find (and sanity-check) value_strings
+    value_strings = findValueStrings(filename, macros, do_extra_checks=extra_value_string_checks)
+    if extra_value_string_checks:
+        for name in value_strings:
+            value_strings[name].extraChecks()
+
+
     # Find important parts of items.
-    items_defined = find_items(filename, macros, check_mask, mask_exact_width, check_label, check_consecutive)
+    items_defined = find_items(filename, macros, value_strings,
+                               check_mask, mask_exact_width, check_label, check_consecutive)
     items_extern_declared = {}
 
     items_declared = {}
@@ -1294,12 +1390,6 @@ def checkFile(filename, check_mask=False, mask_exact_width=False, check_label=Fa
     if check_bitmask_fields:
         field_arrays = find_field_arrays(filename, fields, items_defined)
 
-    # Find (and sanity-check) value_strings
-    value_strings = findValueStrings(filename, macros, do_extra_checks=extra_value_string_checks)
-    if extra_value_string_checks:
-        for name in value_strings:
-            value_strings[name].extraChecks()
-
     if check_mask and check_bitmask_fields:
         for i in items_defined:
             item = items_defined[i]
@@ -1317,7 +1407,7 @@ def checkFile(filename, check_mask=False, mask_exact_width=False, check_label=Fa
                 matches += 1
 
         # Only checking if almost every field does match.
-        checking = len(items_defined) and matches<len(items_defined) and ((matches / len(items_defined)) > 0.9)
+        checking = len(items_defined) and matches<len(items_defined) and ((matches / len(items_defined)) > 0.93)
         if checking:
             print(filename, ':', matches, 'label-vs-filter matches of out of', len(items_defined), 'so reporting mismatches')
             for hf in items_defined:
@@ -1367,6 +1457,7 @@ if args.all_checks:
     args.mask_exact_width = True
     args.consecutive = True
     args.check_bitmask_fields = True
+    #args.label = True
     args.label_vs_filter = True
     args.extra_value_string_checks
 
