@@ -262,6 +262,8 @@ def main():
             manuf = ieee_row[2].strip()
             # The Organization Name field occasionally contains HTML entities. Undo them.
             manuf = html.unescape(manuf)
+            # "Watts A\S"
+            manuf = manuf.replace('\\', '/')
             if manuf == 'IEEE Registration Authority':
                 continue
             if manuf == 'Private':
@@ -306,7 +308,7 @@ def main():
 ''')
 
     # Write the prefix map
-    manuf_fd.write("static manuf_registry_t ieee_registry_table[] = {\n")
+    manuf_fd.write("static const manuf_registry_t ieee_registry_table[] = {\n")
     keys = list(prefix_map.keys())
     keys.sort()
     for oui in keys:
@@ -314,7 +316,7 @@ def main():
     manuf_fd.write("};\n\n")
 
     # write the MA-L table
-    manuf_fd.write("static manuf_oui24_t global_manuf_oui24_table[] = {\n")
+    manuf_fd.write("static const manuf_oui24_t global_manuf_oui24_table[] = {\n")
     keys = list(oui_d[MA_L].keys())
     keys.sort()
     for oui in keys:
@@ -333,7 +335,7 @@ def main():
     manuf_fd.write("};\n\n")
 
     # write the MA-M table
-    manuf_fd.write("static manuf_oui28_t global_manuf_oui28_table[] = {\n")
+    manuf_fd.write("static const manuf_oui28_t global_manuf_oui28_table[] = {\n")
     keys = list(oui_d[MA_M].keys())
     keys.sort()
     for oui in keys:
@@ -352,7 +354,7 @@ def main():
     manuf_fd.write("};\n\n")
 
     #write the MA-S table
-    manuf_fd.write("static manuf_oui36_t global_manuf_oui36_table[] = {\n")
+    manuf_fd.write("static const manuf_oui36_t global_manuf_oui36_table[] = {\n")
     keys = list(oui_d[MA_S].keys())
     keys.sort()
     for oui in keys:
