@@ -9,7 +9,7 @@
 
 #include "config.h"
 
-#include <glib.h>
+#include <wireshark.h>
 
 #include "capture_options_dialog.h"
 #include <ui/qt/widgets/capture_filter_combo.h>
@@ -31,12 +31,13 @@
 #include "ui/capture_ui_utils.h"
 #include "ui/capture_globals.h"
 #include "ui/iface_lists.h"
-#include "ui/last_open_dir.h"
+#include "ui/file_dialog.h"
 
 #include "ui/ws_ui_util.h"
 #include "ui/util.h"
 #include <wsutil/utf8_entities.h>
 #include "ui/preference_utils.h"
+#include "ui/recent.h"
 
 #include <cstdio>
 #include <epan/prefs.h>
@@ -233,7 +234,7 @@ CaptureOptionsDialog::CaptureOptionsDialog(QWidget *parent) :
     connect(mainApp, SIGNAL(localInterfaceListChanged()), this, SLOT(updateLocalInterfaces()));
     connect(ui->browseButton, SIGNAL(clicked()), this, SLOT(browseButtonClicked()));
     connect(ui->interfaceTree, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(itemClicked(QTreeWidgetItem*,int)));
-    connect(ui->interfaceTree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(itemDoubleClicked(QTreeWidgetItem*)));
+    connect(ui->interfaceTree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(itemDoubleClicked(QTreeWidgetItem*,int)));
     connect(ui->tempDirBrowseButton, SIGNAL(clicked()), this, SLOT(tempDirBrowseButtonClicked()));
 
     ui->tabWidget->setCurrentIndex(0);
@@ -365,12 +366,12 @@ void CaptureOptionsDialog::on_capturePromModeCheckBox_toggled(bool checked)
 
 void CaptureOptionsDialog::browseButtonClicked()
 {
-    char *open_dir = NULL;
+    const char *open_dir = NULL;
 
     switch (prefs.gui_fileopen_style) {
 
     case FO_STYLE_LAST_OPENED:
-        open_dir = get_last_open_dir();
+        open_dir = get_open_dialog_initial_dir();
         break;
 
     case FO_STYLE_SPECIFIED:
@@ -504,7 +505,7 @@ void CaptureOptionsDialog::itemClicked(QTreeWidgetItem *item, int column)
         if (device->if_info.type == IF_EXTCAP) {
             /* this checks if configuration is required and not yet provided or saved via prefs */
             QString device_name = ti->data(col_extcap_, Qt::UserRole).value<QString>();
-            if (extcap_has_configuration((const char *)(device_name.toStdString().c_str()), FALSE))
+            if (extcap_has_configuration((const char *)(device_name.toStdString().c_str())))
             {
                 emit showExtcapOptions(device_name, false);
                 return;
@@ -518,29 +519,41 @@ void CaptureOptionsDialog::itemClicked(QTreeWidgetItem *item, int column)
 #endif /* HAVE_LIBPCAP */
 }
 
-void CaptureOptionsDialog::itemDoubleClicked(QTreeWidgetItem *item)
+void CaptureOptionsDialog::itemDoubleClicked(QTreeWidgetItem *item, int column)
 {
     InterfaceTreeWidgetItem *ti = dynamic_cast<InterfaceTreeWidgetItem *>(item);
     if (!ti) return;
 
-#ifdef HAVE_LIBPCAP
-    interface_t *device;
-    QString interface_name = ti->text(col_interface_);
-    device = find_device_by_if_name(interface_name);
-    if (!device) return;
+    switch(column) {
 
-    if (device->if_info.type == IF_EXTCAP) {
-        /* this checks if configuration is required and not yet provided or saved via prefs */
-        QString device_name = ti->data(col_extcap_, Qt::UserRole).value<QString>();
-        if (extcap_has_configuration((const char *)(device_name.toStdString().c_str()), TRUE))
-        {
-            emit showExtcapOptions(device_name, true);
-            return;
+    // Double click starts capture just on columns which are not editable
+    case col_interface_:
+    case col_traffic_:
+    {
+#ifdef HAVE_LIBPCAP
+        interface_t *device;
+        QString interface_name = ti->text(col_interface_);
+        device = find_device_by_if_name(interface_name);
+        if (!device) return;
+
+        if (device->if_info.type == IF_EXTCAP) {
+            /* this checks if configuration is required and not yet provided or saved via prefs */
+            QString device_name = ti->data(col_extcap_, Qt::UserRole).value<QString>();
+            if (extcap_requires_configuration((const char *)(device_name.toStdString().c_str())))
+            {
+                emit showExtcapOptions(device_name, true);
+                return;
+            }
         }
-    }
 #endif /* HAVE_LIBPCAP */
-    emit startCapture();
-    close();
+        emit startCapture();
+        close();
+        break;
+    }
+
+    default:
+        break;
+    }
 }
 
 void CaptureOptionsDialog::on_gbStopCaptureAuto_toggled(bool checked)
@@ -570,7 +583,7 @@ void CaptureOptionsDialog::on_cbUpdatePacketsRT_toggled(bool checked)
 
 void CaptureOptionsDialog::on_cbAutoScroll_toggled(bool checked)
 {
-    auto_scroll_live = checked;
+    recent.capture_auto_scroll = checked;
 }
 
 void CaptureOptionsDialog::on_cbExtraCaptureInfo_toggled(bool checked)
@@ -607,7 +620,7 @@ void CaptureOptionsDialog::on_buttonBox_accepted()
             if (device && device->if_info.type == IF_EXTCAP) {
                 /* this checks if configuration is required and not yet provided or saved via prefs */
                 QString device_name = ti->data(col_extcap_, Qt::UserRole).value<QString>();
-                if (extcap_has_configuration((const char *)(device_name.toStdString().c_str()), TRUE))
+                if (extcap_requires_configuration((const char *)(device_name.toStdString().c_str())))
                 {
                     emit showExtcapOptions(device_name, true);
                     return;
@@ -747,7 +760,7 @@ void CaptureOptionsDialog::updateInterfaces()
     }
 
     ui->cbUpdatePacketsRT->setChecked(global_capture_opts.real_time_mode);
-    ui->cbAutoScroll->setChecked(true);
+    ui->cbAutoScroll->setChecked(recent.capture_auto_scroll);
     ui->cbExtraCaptureInfo->setChecked(global_capture_opts.show_info);
 
     ui->cbResolveMacAddresses->setChecked(gbl_resolv_flags.mac_name);
@@ -1390,7 +1403,7 @@ QWidget* InterfaceTreeDelegate::createEditor(QWidget *parent, const QStyleOption
             QComboBox *cb = new QComboBox(parent);
             cb->addItems(valid_link_types);
 
-            connect(cb, SIGNAL(currentIndexChanged(QString)), this, SLOT(linkTypeChanged(QString)));
+            connect(cb, &QComboBox::currentTextChanged, this, &InterfaceTreeDelegate::linkTypeChanged);
             w = (QWidget*) cb;
             break;
         }
@@ -1445,7 +1458,7 @@ bool InterfaceTreeDelegate::eventFilter(QObject *object, QEvent *event)
     return false;
 }
 
-void InterfaceTreeDelegate::linkTypeChanged(QString selected_link_type)
+void InterfaceTreeDelegate::linkTypeChanged(const QString selected_link_type)
 {
     GList *list;
     link_row *temp;
