@@ -270,7 +270,7 @@ void LteRlcGraphDialog::fillGraph()
                     acks_time, acks,
                     nacks_time, nacks;
     for (struct rlc_segment *seg = graph_.segments; seg != NULL; seg = seg->next) {
-        double ts = seg->rel_secs + seg->rel_usecs / 1000000.0;
+        double ts = seg->rel_secs + (seg->rel_usecs / 1000000.0);
         if (compareHeaders(seg)) {
             if (!seg->isControlPDU) {
                 // Data
@@ -542,9 +542,9 @@ void LteRlcGraphDialog::graphClicked(QMouseEvent *event)
         // XXX We should find some way to get rlcPlot to handle a
         // contextMenuEvent instead.
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0 ,0)
-        ctx_menu_->exec(event->globalPosition().toPoint());
+        ctx_menu_->popup(event->globalPosition().toPoint());
 #else
-        ctx_menu_->exec(event->globalPos());
+        ctx_menu_->popup(event->globalPos());
 #endif
     } else  if (mouse_drags_) {
         if (rp->axisRect()->rect().contains(event->pos())) {
@@ -618,7 +618,7 @@ void LteRlcGraphDialog::mouseMoved(QMouseEvent *event)
         hint += tr("%1 %2 (%3s seq %4 len %5)")
                 .arg(cap_file_.capFile() ? tr("Click to select packet") : tr("Packet"))
                 .arg(packet_num_)
-                .arg(QString::number(packet_seg->rel_secs + packet_seg->rel_usecs / 1000000.0, 'g', 4))
+                .arg(QString::number(packet_seg->rel_secs + (packet_seg->rel_usecs / 1000000.0), 'g', 4))
                 .arg(packet_seg->SN)
                 .arg(packet_seg->pduLength);
         tracer_->setGraphKey(ui->rlcPlot->xAxis->pixelToCoord(event->pos().x()));
@@ -850,7 +850,7 @@ void LteRlcGraphDialog::on_otherDirectionButton_clicked()
 void LteRlcGraphDialog::on_buttonBox_accepted()
 {
     QString file_name, extension;
-    QDir path(mainApp->lastOpenDir());
+    QDir path(mainApp->openDialogInitialDir());
     QString pdf_filter = tr("Portable Document Format (*.pdf)");
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
