@@ -266,7 +266,8 @@ void MainStatusBar::setStatusbarForCaptureFile()
         QString msgtip = QString("%1 (%2)")
                 .arg(cap_file_->filename)
                 .arg(file_size_to_qstring(cap_file_->f_datalen));
-        pushGenericStatus(STATUS_CTX_FILE, cf_get_display_name(cap_file_), msgtip);
+        pushGenericStatus(STATUS_CTX_FILE,
+                gchar_free_to_qstring(cf_get_display_name(cap_file_)), msgtip);
     }
 }
 
@@ -384,55 +385,50 @@ void MainStatusBar::showCaptureStatistics()
 #ifdef HAVE_LIBPCAP
     if (cap_file_) {
         /* Do we have any packets? */
-        if (cs_fixed_ && cs_count_ > 0) {
-            if (prefs.gui_qt_show_selected_packet && rows.count() == 1) {
-                packets_str.append(QString(tr("Selected Packet: %1 %2 "))
-                                   .arg(rows.at(0))
-                                   .arg(UTF8_MIDDLE_DOT));
-            }
-            packets_str.append(QString(tr("Packets: %1"))
-                               .arg(cs_count_));
-        } else if (cs_count_ > 0) {
-            if (prefs.gui_qt_show_selected_packet && rows.count() == 1) {
+        if (!cs_fixed_) {
+            cs_count_ = cap_file_->count;
+        }
+        if (cs_count_ > 0) {
+            if (prefs.gui_show_selected_packet && rows.count() == 1) {
                 packets_str.append(QString(tr("Selected Packet: %1 %2 "))
                                    .arg(rows.at(0))
                                    .arg(UTF8_MIDDLE_DOT));
             }
             packets_str.append(QString(tr("Packets: %1 %4 Displayed: %2 (%3%)"))
-                               .arg(cap_file_->count)
+                               .arg(cs_count_)
                                .arg(cap_file_->displayed_count)
-                               .arg((100.0*cap_file_->displayed_count)/cap_file_->count, 0, 'f', 1)
+                               .arg((100.0*cap_file_->displayed_count)/cs_count_, 0, 'f', 1)
                                .arg(UTF8_MIDDLE_DOT));
             if (rows.count() > 1) {
                 packets_str.append(QString(tr(" %1 Selected: %2 (%3%)"))
                                    .arg(UTF8_MIDDLE_DOT)
                                    .arg(rows.count())
-                                   .arg((100.0*rows.count())/cap_file_->count, 0, 'f', 1));
+                                   .arg((100.0*rows.count())/cs_count_, 0, 'f', 1));
             }
             if (cap_file_->marked_count > 0) {
                 packets_str.append(QString(tr(" %1 Marked: %2 (%3%)"))
                                    .arg(UTF8_MIDDLE_DOT)
                                    .arg(cap_file_->marked_count)
-                                   .arg((100.0*cap_file_->marked_count)/cap_file_->count, 0, 'f', 1));
+                                   .arg((100.0*cap_file_->marked_count)/cs_count_, 0, 'f', 1));
             }
             if (cap_file_->drops_known) {
                 packets_str.append(QString(tr(" %1 Dropped: %2 (%3%)"))
                                    .arg(UTF8_MIDDLE_DOT)
                                    .arg(cap_file_->drops)
-                                   .arg((100.0*cap_file_->drops)/cap_file_->count, 0, 'f', 1));
+                                   .arg((100.0*cap_file_->drops)/cs_count_, 0, 'f', 1));
             }
             if (cap_file_->ignored_count > 0) {
                 packets_str.append(QString(tr(" %1 Ignored: %2 (%3%)"))
                                    .arg(UTF8_MIDDLE_DOT)
                                    .arg(cap_file_->ignored_count)
-                                   .arg((100.0*cap_file_->ignored_count)/cap_file_->count, 0, 'f', 1));
+                                   .arg((100.0*cap_file_->ignored_count)/cs_count_, 0, 'f', 1));
             }
             if (cap_file_->packet_comment_count > 0) {
                 packets_str.append(QString(tr(" %1 Comments: %2"))
                     .arg(UTF8_MIDDLE_DOT)
                     .arg(cap_file_->packet_comment_count));
             }
-            if (prefs.gui_qt_show_file_load_time && !cap_file_->is_tempfile) {
+            if (prefs.gui_show_file_load_time && !cap_file_->is_tempfile) {
                 /* Loading an existing file */
                 gulong computed_elapsed = cf_get_computed_elapsed(cap_file_);
                 packets_str.append(QString(tr(" %1  Load time: %2:%3.%4"))
@@ -442,6 +438,15 @@ void MainStatusBar::showCaptureStatistics()
                                    .arg(computed_elapsed%1000, 3, 10, QLatin1Char('0')));
             }
         }
+    } else if (cs_fixed_ && cs_count_ > 0) {
+        /* There shouldn't be any rows without a cap_file_ but this is benign */
+        if (prefs.gui_show_selected_packet && rows.count() == 1) {
+            packets_str.append(QString(tr("Selected Packet: %1 %2 "))
+                .arg(rows.at(0))
+                .arg(UTF8_MIDDLE_DOT));
+        }
+        packets_str.append(QString(tr("Packets: %1"))
+            .arg(cs_count_));
     }
 #endif // HAVE_LIBPCAP
 
@@ -491,10 +496,10 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
 {
     ProfileModel model;
 
-    QMenu * profile_menu_ = new QMenu(this);
-    profile_menu_->setAttribute(Qt::WA_DeleteOnClose);
-    QActionGroup * global = new QActionGroup(profile_menu_);
-    QActionGroup * user = new QActionGroup(profile_menu_);
+    QMenu * profile_menu = new QMenu(this);
+    profile_menu->setAttribute(Qt::WA_DeleteOnClose);
+    QActionGroup * global = new QActionGroup(profile_menu);
+    QActionGroup * user = new QActionGroup(profile_menu);
 
     for (int cnt = 0; cnt < model.rowCount(); cnt++)
     {
@@ -512,7 +517,7 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
 
         if (idx.data(ProfileModel::DATA_IS_DEFAULT).toBool())
         {
-            pa = profile_menu_->addAction(name);
+            pa = profile_menu->addAction(name);
         }
         else if (idx.data(ProfileModel::DATA_IS_GLOBAL).toBool())
         {
@@ -537,12 +542,12 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
         connect(pa, &QAction::triggered, this, &MainStatusBar::switchToProfile);
     }
 
-    profile_menu_->addActions(user->actions());
-    profile_menu_->addSeparator();
-    profile_menu_->addActions(global->actions());
+    profile_menu->addActions(user->actions());
+    profile_menu->addSeparator();
+    profile_menu->addActions(global->actions());
 
     if (button == Qt::LeftButton) {
-        profile_menu_->popup(global_pos);
+        profile_menu->popup(global_pos);
     } else {
 
         bool enable_edit = false;
@@ -551,7 +556,7 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
         if (! idx.data(ProfileModel::DATA_IS_DEFAULT).toBool() && ! idx.data(ProfileModel::DATA_IS_GLOBAL).toBool())
             enable_edit = true;
 
-        profile_menu_->setTitle(tr("Switch to"));
+        profile_menu->setTitle(tr("Switch to"));
         QMenu * ctx_menu_ = new QMenu(this);
         ctx_menu_->setAttribute(Qt::WA_DeleteOnClose);
         QAction * action = ctx_menu_->addAction(tr("Manage Profiles…"), this, SLOT(manageProfile()));
@@ -570,9 +575,9 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
 
 #ifdef HAVE_MINIZIP
         QMenu * importMenu = new QMenu(tr("Import"));
-        action = importMenu->addAction(tr("from zip file"), this, SLOT(manageProfile()));
+        action = importMenu->addAction(tr("From Zip File..."), this, SLOT(manageProfile()));
         action->setProperty("dialog_action_", (int)ProfileDialog::ImportZipProfile);
-        action = importMenu->addAction(tr("from directory"), this, SLOT(manageProfile()));
+        action = importMenu->addAction(tr("From Directory..."), this, SLOT(manageProfile()));
         action->setProperty("dialog_action_", (int)ProfileDialog::ImportDirProfile);
         ctx_menu_->addMenu(importMenu);
 
@@ -581,11 +586,11 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
             QMenu * exportMenu = new QMenu(tr("Export"), ctx_menu_);
             if (enable_edit)
             {
-                action = exportMenu->addAction(tr("selected personal profile"), this, SLOT(manageProfile()));
+                action = exportMenu->addAction(tr("Selected Personal Profile..."), this, SLOT(manageProfile()));
                 action->setProperty("dialog_action_", (int)ProfileDialog::ExportSingleProfile);
                 action->setEnabled(enable_edit);
             }
-            action = exportMenu->addAction(tr("all personal profiles"), this, SLOT(manageProfile()));
+            action = exportMenu->addAction(tr("All Personal Profiles..."), this, SLOT(manageProfile()));
             action->setProperty("dialog_action_", (int)ProfileDialog::ExportAllProfiles);
             ctx_menu_->addMenu(exportMenu);
         }
@@ -596,7 +601,7 @@ void MainStatusBar::showProfileMenu(const QPoint &global_pos, Qt::MouseButton bu
 #endif
         ctx_menu_->addSeparator();
 
-        ctx_menu_->addMenu(profile_menu_);
+        ctx_menu_->addMenu(profile_menu);
         ctx_menu_->popup(global_pos);
     }
 }
@@ -630,10 +635,11 @@ void MainStatusBar::manageProfile()
     QAction *pa = qobject_cast<QAction*>(sender());
 
     if (pa) {
-        ProfileDialog cp_dialog;
+        ProfileDialog * cp_dialog = new ProfileDialog(this);
+        cp_dialog->setAttribute(Qt::WA_DeleteOnClose);
 
         int profileAction = pa->property("dialog_action_").toInt();
-        cp_dialog.execAction(static_cast<ProfileDialog::ProfileAction>(profileAction));
+        cp_dialog->execAction(static_cast<ProfileDialog::ProfileAction>(profileAction));
     }
 }
 
@@ -648,6 +654,9 @@ void MainStatusBar::captureEventHandler(CaptureEvent ev)
         case CaptureEvent::Continued:
             updateCaptureStatistics(ev.capSession());
             break;
+        case CaptureEvent::Finished:
+            updateCaptureStatistics(ev.capSession());
+            break;
         default:
             break;
         }
