@@ -45,8 +45,6 @@
 // - ACK & RWIN segment ticks in tcptrace graph
 // - Add missing elements (retrans, URG, SACK, etc) to tcptrace. It probably makes
 //   sense to subclass QCPGraph for this.
-// - Allow switching the tracer between graphs when there are two / selecting
-//   the other graph, at the very least if base_graph_ is disabled.
 
 // The GTK+ version computes a 20 (or 21!) segment moving average. Comment
 // out the line below to use that. By default we use a 1 second MA.
@@ -75,7 +73,6 @@ const QString segment_length_label_ = QObject::tr("Segment Length (B)");
 const QString sequence_number_label_ = QObject::tr("Sequence Number (B)");
 const QString time_s_label_ = QObject::tr("Time (s)");
 const QString window_size_label_ = QObject::tr("Window Size (B)");
-const QString cwnd_label_ = QObject::tr("Unacked (Outstanding) Bytes (B)");
 
 QCPErrorBarsNotSelectable::QCPErrorBarsNotSelectable(QCPAxis *keyAxis, QCPAxis *valueAxis) :
     QCPErrorBars(keyAxis, valueAxis)
@@ -134,6 +131,8 @@ TCPStreamDialog::TCPStreamDialog(QWidget *parent, capture_file *cf, tcp_graph_ty
     if (parent) loadGeometry(parent->width() * 2 / 3, parent->height() * 4 / 5);
     setAttribute(Qt::WA_DeleteOnClose, true);
 
+    ui->streamNumberSpinBox->setStyleSheet("QSpinBox { min-width: 2em; }");
+
     guint32 th_stream = select_tcpip_session(cap_file_);
     if (th_stream == G_MAXUINT32) {
         done(QDialog::Rejected);
@@ -293,7 +292,7 @@ TCPStreamDialog::TCPStreamDialog(QWidget *parent, capture_file *cf, tcp_graph_ty
     sack2_eb_->setDataPlottable(sack2_graph_);
 
     // RWin graph - displays upper extent of RWIN advertised on reverse packets
-    rwin_graph_ = sp->addGraph(sp->xAxis, sp->yAxis2);
+    rwin_graph_ = sp->addGraph();
     rwin_graph_->setPen(QPen(QBrush(graph_color_3), pen_width));
     rwin_graph_->setLineStyle(QCPGraph::lsStepLeft);
 
@@ -354,6 +353,7 @@ TCPStreamDialog::TCPStreamDialog(QWidget *parent, capture_file *cf, tcp_graph_ty
     connect(sp, SIGNAL(axisClick(QCPAxis*,QCPAxis::SelectablePart,QMouseEvent*)),
             this, SLOT(axisClicked(QCPAxis*,QCPAxis::SelectablePart,QMouseEvent*)));
     connect(sp->yAxis, SIGNAL(rangeChanged(QCPRange)), this, SLOT(transformYRange(QCPRange)));
+    disconnect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     this->setResult(QDialog::Accepted);
 }
 
@@ -1580,18 +1580,9 @@ void TCPStreamDialog::fillWindowScale()
             }
         }
     }
-    /* base_graph_ is the one that the tracer is on and allows selecting
-     * segments. XXX - Is the congestion window more interesting to see
-     * the exact value and select?
-     */
     base_graph_->setData(cwnd_time, cwnd_size);
     rwin_graph_->setData(rel_time, win_size);
-    sp->yAxis->setLabel(cwnd_label_);
-
-    sp->yAxis2->setLabel(window_size_label_);
-    sp->yAxis2->setLabelColor(QColor(graph_color_3));
-    sp->yAxis2->setTickLabelColor(QColor(graph_color_3));
-    sp->yAxis2->setVisible(true);
+    sp->yAxis->setLabel(window_size_label_);
 }
 
 QString TCPStreamDialog::streamDescription()
@@ -1781,7 +1772,7 @@ void TCPStreamDialog::mouseMoved(QMouseEvent *event)
             tracer_->setVisible(false);
             hint += "Hover over the graph for details. " + stream_desc_ + "</i></small>";
             ui->hintLabel->setText(hint);
-            ui->streamPlot->replot(QCustomPlot::rpQueuedReplot);
+            ui->streamPlot->replot();
             return;
         }
 
@@ -1796,7 +1787,7 @@ void TCPStreamDialog::mouseMoved(QMouseEvent *event)
                 .arg(packet_seg->th_ack)
                 .arg(packet_seg->th_win);
         tracer_->setGraphKey(ui->streamPlot->xAxis->pixelToCoord(event->pos().x()));
-        sp->replot(QCustomPlot::rpQueuedReplot);
+        sp->replot();
     } else {
         if (rubber_band_ && rubber_band_->isVisible() && event) {
             rubber_band_->setGeometry(QRect(rb_origin_, event->pos()).normalized());
@@ -1854,7 +1845,7 @@ void TCPStreamDialog::transformYRange(const QCPRange &y_range1)
 void TCPStreamDialog::on_buttonBox_accepted()
 {
     QString file_name, extension;
-    QDir path(mainApp->lastOpenDir());
+    QDir path(mainApp->openDialogInitialDir());
     QString pdf_filter = tr("Portable Document Format (*.pdf)");
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
