@@ -17,7 +17,7 @@
 
 #include <ui/qt/widgets/capture_filter_combo.h>
 #include <ui/qt/utils/color_utils.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 CaptureFilterCombo::CaptureFilterCombo(QWidget *parent, bool plain) :
     QComboBox(parent),
@@ -44,8 +44,8 @@ CaptureFilterCombo::CaptureFilterCombo(QWidget *parent, bool plain) :
             this, &CaptureFilterCombo::captureFilterSyntaxChanged);
     connect(cf_edit_, &CaptureFilterEdit::startCapture, this, &CaptureFilterCombo::startCapture);
     connect(cf_edit_, &CaptureFilterEdit::startCapture, this, &CaptureFilterCombo::saveAndRebuildFilterList);
-    connect(wsApp, &WiresharkApplication::appInitialized, this, &CaptureFilterCombo::rebuildFilterList);
-    connect(wsApp, &WiresharkApplication::preferencesChanged, this, &CaptureFilterCombo::rebuildFilterList);
+    connect(mainApp, &MainApplication::appInitialized, this, &CaptureFilterCombo::rebuildFilterList);
+    connect(mainApp, &MainApplication::preferencesChanged, this, &CaptureFilterCombo::rebuildFilterList);
 
     rebuildFilterList();
     clearEditText();
@@ -95,7 +95,7 @@ void CaptureFilterCombo::updateStyleSheet()
                 "QComboBox::drop-down {"
                 "  subcontrol-origin: padding;"
                 "  subcontrol-position: top right;"
-                "  width: 16px;"
+                "  width: 14px;"
                 "  border-left-width: 0px;"
                 " }"
 
@@ -126,7 +126,7 @@ void CaptureFilterCombo::rebuildFilterList()
     QString cur_filter = currentText();
     clear();
     for (GList *li = g_list_first(cfilter_list); li != NULL; li = gxx_list_next(li)) {
-        addItem(gxx_list_data(const gchar *, li));
+        insertItem(0, gxx_list_data(const gchar *, li));
     }
     lineEdit()->setText(cur_filter);
     lineEdit()->blockSignals(false);
