@@ -8,6 +8,8 @@
  */
 #include "config.h"
 
+#define WS_LOG_DOMAIN LOG_DOMAIN_WIRETAP
+
 #include <glib.h>
 #include <string.h>
 
@@ -1710,6 +1712,27 @@ static void dsb_copy_mand(wtap_block_t dest_block, wtap_block_t src_block)
     dst->secrets_data = (guint8 *)g_memdup2(src->secrets_data, src->secrets_len);
 }
 
+static void sysdig_mev_create(wtap_block_t block)
+{
+    block->mandatory_data = g_new0(wtapng_sysdig_mev_mandatory_t, 1);
+}
+
+static void sysdig_mev_free_mand(wtap_block_t block)
+{
+    wtapng_sysdig_mev_mandatory_t *mand = (wtapng_sysdig_mev_mandatory_t *)block->mandatory_data;
+    g_free(mand->mev_data);
+}
+
+static void sysdig_mev_copy_mand(wtap_block_t dest_block, wtap_block_t src_block)
+{
+    wtapng_sysdig_mev_mandatory_t *src = (wtapng_sysdig_mev_mandatory_t *)src_block->mandatory_data;
+    wtapng_sysdig_mev_mandatory_t *dst = (wtapng_sysdig_mev_mandatory_t *)dest_block->mandatory_data;
+    dst->mev_type = src->mev_type;
+    dst->mev_data_len = src->mev_data_len;
+    g_free(dst->mev_data);
+    dst->mev_data = (guint8 *)g_memdup2(src->mev_data, src->mev_data_len);
+}
+
 static void pkt_create(wtap_block_t block)
 {
     /* Commented out for now, there's no mandatory data that isn't handled by
@@ -1921,6 +1944,16 @@ void wtap_opttypes_initialize(void)
         0
     };
 
+    static wtap_blocktype_t sysdig_mev_block = {
+        WTAP_BLOCK_SYSDIG_META_EVENT,
+        "Sysdig MEV",
+        "Sysdig Meta Event Block",
+        sysdig_mev_create,
+        sysdig_mev_free_mand,
+        sysdig_mev_copy_mand,
+        NULL
+    };
+
     static wtap_blocktype_t pkt_block = {
         WTAP_BLOCK_PACKET,            /* block_type */
         "EPB/SPB/PB",                 /* name */
@@ -2033,6 +2066,11 @@ void wtap_opttypes_initialize(void)
      */
     wtap_opttype_block_register(&dsb_block);
 
+    /*
+     * Register the Sysdig MEV, currently no options are defined.
+     */
+    wtap_opttype_block_register(&sysdig_mev_block);
+
     /*
      * Register EPB/SPB/PB and the options that can appear in it/them.
      * NB: Simple Packet Blocks have no options.
